JavaScript Load Image
Description: JavaScript Load Image is a library to load images provided as File or Blob objects or via URL. It returns an optionally scaled and/or cropped HTML img or canvas element. It also provides a method to parse image meta data to extract Exif tags and thumbnails and to restore the complete image header after resizing.

# JavaScript Load Image Demo

JavaScript Load Image is a library to load images provided as File or Blob objects or via URL.
It returns an optionally scaled and/or cropped HTML img or canvas element.
It also provides a method to parse image meta data to extract Exif tags and thumbnails and to restore the complete image header after resizing.

## Select an image file

Or drag & drop an image file onto this webpage.

## Result

This demo works only in browsers with support for the URL or FileReader API.

## Exif meta data